#
# spec file for package gtk-sharp2
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name gtk-sharp

%ifnarch ppc64 ppc64le s390x
%bcond_without monodoc
%else
%bcond_with monodoc
%endif
Name:           gtk-sharp2
URL:            https://github.com/mono/gtk-sharp
Summary:        .Net Language Bindings for GTK+
License:        GPL-2.0-only
Group:          System/GUI/GNOME
%ifarch ppc64
Obsoletes:      gtk-sharp2-64bit
%endif
%ifarch  %ix86 ppc
Obsoletes:      gtk-sharp2-32bit
%endif
BuildRequires:  gtkhtml2-devel
BuildRequires:  libglade2-devel
BuildRequires:  librsvg-devel
BuildRequires:  libtool
BuildRequires:  mono-devel
%if %{with monodoc}
BuildRequires:  monodoc-core
%endif
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
BuildRequires:  vte-devel
Version:        2.12.45
Release:        4.4
Source0:        https://download.mono-project.com/sources/gtk-sharp212/%{_name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE fix "64bit-portability-issue" error at windowmanager.c:113
Patch1:         fix-64bit-portability-issue.patch
# PATCH-FIX-UPSTREAM gtk-sharp2-csharp8.patch dimstar@opensuse.org -- Fix build failure with mcs caused by C#8 changes in mcs
Patch2:         gtk-sharp2-csharp8.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package contains Mono bindings for gtk+, gdk, atk, and pango.

%package gapi
Summary:        C Source Parser and C Generator
License:        GPL-2.0-only
Group:          System/GUI/GNOME
Requires:       perl-XML-LibXML
Requires:       perl-XML-LibXML-Common
Requires:       perl-XML-SAX

%description gapi
The gtk-sharp-gapi package includes the parser and code generator used
by the GTK if you want to bind GObject-based libraries, or need to
compile a project that uses it to bind such a library.

%package -n gtk-sharp2-doc
Summary:        Monodoc documentation for gtk-sharp2
License:        LGPL-2.1-only
Group:          System/GUI/GNOME

%description -n gtk-sharp2-doc
This package contains the gtk-sharp2 documentation for monodoc.

%package -n glib-sharp2
Summary:        Mono bindings for glib
License:        LGPL-2.1-only
Group:          System/GUI/GNOME

%description -n glib-sharp2
This package contains Mono bindings for glib.

%package -n glade-sharp2
Summary:        Mono bindings for glade
License:        LGPL-2.1-only
Group:          System/GUI/GNOME
Requires:       libglade-2_0-0

%description -n glade-sharp2
This package contains Mono bindings for glade.

%package -n gtk-sharp2-complete
Summary:        GTK+ and GNOME bindings for Mono (virtual package)
License:        LGPL-2.1-only
Group:          System/GUI/GNOME
Requires:       glade-sharp2 = %{version}-%{release}
Requires:       glib-sharp2 = %{version}-%{release}
Requires:       gtk-sharp2 = %{version}-%{release}
Requires:       gtk-sharp2-doc = %{version}-%{release}
Requires:       gtk-sharp2-gapi = %{version}-%{release}

%description -n gtk-sharp2-complete
Gtk# is a library that allows you to build fully native graphical GNOME
applications using Mono. Gtk# is a binding to GTK+, the cross platform
user interface toolkit used in GNOME. It includes bindings for Gtk,
Atk, Pango, Gdk, libgnome, libgnomeui and libgnomecanvas.  (Virtual
package which depends on all gtk-sharp2 subpackages)

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
autoreconf -fiv
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
# That should come frmo mono-core now
#export MONO_CAIRO_LIBS=$(pkg-config --libs mono-cairo | sed 's:2.0:4.5:')
%configure --libexecdir=%{_prefix}/lib --enable-debug
make

%install
export MONO_GAC_PREFIX=%{buildroot}%{_prefix}
make install DESTDIR=%{buildroot}
rm %{buildroot}%{_libdir}/*.*a

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%post -n glib-sharp2 -p /sbin/ldconfig
%postun -n glib-sharp2 -p /sbin/ldconfig

%files
%defattr(-, root, root)
%{_libdir}/libatksharpglue-2.so
%{_libdir}/libgdksharpglue-2.so
%{_libdir}/libgtksharpglue-2.so
%{_libdir}/libpangosharpglue-2.so
%{_libdir}/pkgconfig/gtk-sharp-2.0.pc
%{_libdir}/pkgconfig/gtk-dotnet-2.0.pc
%{_prefix}/lib/mono/gac/*atk-sharp
%{_prefix}/lib/mono/gtk-sharp-2.0/*atk-sharp.dll
%{_prefix}/lib/mono/gac/*gdk-sharp
%{_prefix}/lib/mono/gtk-sharp-2.0/*gdk-sharp.dll
%{_prefix}/lib/mono/gac/*gtk-dotnet
%{_prefix}/lib/mono/gtk-sharp-2.0/*gtk-dotnet.dll
%{_prefix}/lib/mono/gac/*gtk-sharp
%{_prefix}/lib/mono/gtk-sharp-2.0/*gtk-sharp.dll
%{_prefix}/lib/mono/gac/*pango-sharp
%{_prefix}/lib/mono/gtk-sharp-2.0/*pango-sharp.dll

%files gapi
%defattr(-, root, root)
%{_bindir}/gapi2-codegen
%{_bindir}/gapi2-fixup
%{_bindir}/gapi2-parser
%{_datadir}/gapi-2.0
%{_libdir}/pkgconfig/gapi-2.0.pc
%{_prefix}/lib/gtk-sharp-2.0/gapi_codegen.exe
%{_prefix}/lib/gtk-sharp-2.0/gapi-fixup.exe
%{_prefix}/lib/gtk-sharp-2.0/gapi-parser.exe
%{_prefix}/lib/gtk-sharp-2.0/gapi_pp.pl
%{_prefix}/lib/gtk-sharp-2.0/gapi2xml.pl

%files -n gtk-sharp2-doc
%defattr(-, root, root)
%doc COPYING ChangeLog README
%if %{with monodoc}
%{_prefix}/lib/monodoc
%endif

%files -n glib-sharp2
%defattr(-, root, root)
%{_libdir}/libglibsharpglue-2.so
%{_libdir}/pkgconfig/glib-sharp-2.0.pc
%{_prefix}/lib/mono/gac/*glib-sharp
%{_prefix}/lib/mono/gtk-sharp-2.0/*glib-sharp.dll

%files -n glade-sharp2
%defattr(-, root, root)
%{_libdir}/libgladesharpglue-2.so
%{_libdir}/pkgconfig/glade-sharp-2.0.pc
%{_prefix}/lib/mono/gac/*glade-sharp
%{_prefix}/lib/mono/gtk-sharp-2.0/*glade-sharp.dll

%files -n gtk-sharp2-complete
%defattr(-, root, root)
%dir %{_prefix}/lib/mono/gtk-sharp-2.0
%dir %{_prefix}/lib/gtk-sharp-2.0

%changelog
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Nov  1 2021 Michael Gorse <mgorse@suse.com>
- Disable docs on ppc64 and s390x. Mdoc.exe currently isn't
  available there.
* Tue Mar  2 2021 Marguerite Su <i@marguerite.su>
- glade-sharp2 requires libglade-2_0-0 (boo#1177544)
* Wed Jan 29 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.12.45: no changelogs provided.
- Add gtk-sharp2-csharp8.patch: Fix build failure with mcs caused
  by C#8 changes in mcs. Fixes build with mono-core 6.4.
* Wed Feb  7 2018 fwdsbs.to.11df@xoxy.net
- Update version to 2.12.41 from project's github page: https://github.com/mono/gtk-sharp/releases
- Remove patch: gtk-sharp2-glib-2_31.patch
- Remove patch: gtk-sharp2-gmcs-as-compiler.patch
- Add fix-64bit-portability-issue.patch:
  * fix "64bit-portability-issue" error at windowmanager.c:113
* Wed Sep 28 2016 fwdsbs.to.11df@xoxy.net
- fix install phase: set MONO_GAC_PREFIX env variable pointing to %%{buildroot}%%{_prefix}.
  gacutil from mono >= 4.6 need this variable to find libraries installed in non-default gac location, even if this location provided by "root" or "gacdir" cmdline option
* Mon Dec  7 2015 lnussel@suse.de
- run ldconfig in post/postun also in glib-sharp2 package
* Fri Dec  4 2015 meissner@suse.com
- run ldconfig in post/postun
* Mon Jan 28 2013 dimstar@opensuse.org
- Add gtk-sharp2-gmcs-as-compiler.patch: Choose gmcs as the
  prefered compiler. This will build gtk sharp2 with .Net runtime
  4.0.
- Add libtool BuildRequires and call to autoreconf, as above patch
  touches the build system.
* Thu Feb  9 2012 dimstar@opensuse.org
- Add gtk-sharp2-glib-2_31.patch: Only glib.h can be #include'd
  with glib 2.31.
* Sat Nov  6 2010 aj@suse.de
- Readd glade-sharp2 which was lost in last change.
* Wed Nov  3 2010 ajorgensen@novell.com
- Cleanup spec file
* Sat May 15 2010 coolo@novell.com
- avoid gnome-panel dependency to avoid build cycle
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Tue Mar 16 2010 ajorgensen@novell.com
- Update to 2.12.10
  * Bugfix release
* Tue Aug 11 2009 ajorgensen@novell.com
- Update to 2.12.9
  * Bugfix release
* Tue Mar 31 2009 ajorgensen@novell.com
- Update to 2.4
  * http://www.mono-project.com/Release_Notes_Mono_2.4
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Mon Dec  1 2008 ajorgensen@novell.com
- Fix for bnc#450119
* Mon Nov 24 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Fri Nov  7 2008 ajorgensen@novell.com
- Update to 2.12.6
  * Critical signal crash bugfix for bgo#555242
  * Atk API cleanup
  * minor GLib and Gtk bugfixes
* Fri Nov  7 2008 jjohnny@novell.com
- support for custom marshalling hooks (bgo#555242)
* Wed Oct 22 2008 ajorgensen@novell.com
- Update to 2.12.5
  * Fix for bnc#400595
  * Assembly Reference Loading Fix (bnc#426876)
  * Atk API cleanup
  * Win32 installer build integration
* Tue Sep 23 2008 ajorgensen@novell.com
- Update to 2.12.4
  * Bugfixes for bnc#427588 and bnc#384475
* Wed Sep 10 2008 ajorgensen@novell.com
- Update to 2.12.3
  * Bugfixes including bnc#387220, bnc#411444, and bnc#423450
* Tue Sep  9 2008 ajorgensen@novell.com
- Restore 2.8 version of tarball so we can build on SLE10
- Fix logic for patches
* Fri Aug 22 2008 ajorgensen@novell.com
- Update to 2.12.2
  * Extensive Atk# API cleanup (Andres Aragoneses, Brad Taylor, and MK)
  * Signal EmissionHook and Emit implementations (Andres and MK)
  * GObject Property Registration (Christian Hoff)
  * Interface and VirtualMethod improvements (Christian Hoff)
  * Bugfixing (Andres Aragoneses, Stephane Delcroix, Lluis Sanchez Gual, Christian Hoff & MK)
* Thu May  8 2008 aj@suse.de
- Fix warnings about missing return.
* Thu Apr 24 2008 wberrier@suse.de
- Update to 2.12.1
  * Bugfix in GLib ref management for Gnome.Program crash in
  gnome-sharp
  * Enhanced Null-terminated string array marshaling
  * Bugfixes for Pango.AttrList
  * Added missing virtual methods and some reference management
  fixes in Atk
  * Bugfix for crash in Gtk.KeySnoopFunc delegate marshaling
  * PrintOperation cairo context reference management fix
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Apr  2 2008 wberrier@suse.de
- Packaging updates to allow building of 2.12.0, and still build
  older versions (for the build service)
- Simplify (hopefully) version choosing for each distro
- Tie differences between gtk# versions to versions and not
  distros
- Update to 2.12.0
  - Memory and Reference Management Improvements
  - Gtk.Object destruction enhancements
  - Revamped the GLib.Object finalization mechanism
  - Better exception handling
  - Structure marshaling
  - GInterface Registration
* Tue Mar 25 2008 wberrier@suse.de
- Remove off_t patch now that it's in 2.10.4
- Update to 2.10.4
  - Various gug fixes, including: bnc #359561
- Changes in 2.10.3:
  - Performance, memory management, and object finalization
  improvements.
  - GLib.ExceptionManager to support exception handling in signal
  callbacks.
  - GLib.IOChannel and GLib.Spawn classes for process spawning.
  - Numerous bugfixes
* Wed Dec  5 2007 sbrabec@suse.cz
- Handle off_t as long (#319824),
* Fri Aug  3 2007 wberrier@suse.de
- Update to bigfix release: 2.10.2
  - Bugfixes: bugzilla.ximian.com:
  - 82287, 78524, 79214, 82037, 82098, 82115
- Remove fix_callback_code_generator.patch, as it's been fixed in
  2.10.2
* Sun Jul 15 2007 aj@suse.de
- Add fix_callback_code_generator.patch to fix gapi's code
  generator for callbacks with out parameters (fixes gmime-sharp).
* Tue Jul  3 2007 wberrier@suse.de
- Correct time for May 2 entry (failing on s390 machines)
- Update to 2.10 for distros with gtk 2.10 (currently this is
  opensuse 10.2, 10.3, and fedora 7)
  - Make all subpackages that are in the new gnome-sharp package
  conditional for 2.10 and newer, leave them there for 2.8 and
  older)
  - 2.10.1 Changes:
  - Memory leak and other various fixes
  - 2.10 Changes:
  - subpackages split between platform/desktop for inclusion into
  Gnome (based on gtk# 2.8.3)
* Sat Jun 16 2007 wberrier@suse.de
- Correct time for May 2 entry (failing on s390 machines)
* Thu May 17 2007 wberrier@novell.com
- make sure vte is installed during suse 10.0 build to resolve
  .config dllmaps
* Fri May  4 2007 wberrier@novell.com
- revert_unportable_relocatable.patch so that the fedora packages
  don't need to depend on the 'which' package
* Thu May  3 2007 wberrier@novell.com
- Use the internally defined deps/reqs since the suse rpm support
  doesn't look for assembly .config files
  (set _use_internal_dependency_generator to 0 on fedora distros)
* Wed May  2 2007 wberrier@novell.com
- Rely on the new .config rpm dep generation for requires for:
  gtkhtml-sharp2
  rsvg-sharp2
  gnome-vfs-sharp2
  vte-sharp2
  (Also simplifies cross distro packaging, mainly suse vs. redhat)
* Thu Apr 26 2007 wberrier@suse.de
- Fix vte .so version in the .config file (fixes bnc #265854)
* Fri Apr 13 2007 wberrier@novell.com
- add %%debug_package so debug packages get created
* Wed Apr 11 2007 wberrier@novell.com
- Add mono dep/req for older distros
* Thu Apr  5 2007 wberrier@novell.com
- Adapt for build service, final fix (at least hopefully for a long
  time) for gtkhtml
* Tue Mar 27 2007 sbrabec@suse.cz
- Build with the latest gtkhtml.
* Wed Jan 17 2007 meissner@suse.de
- use RPM_OPT_FLAGS.
* Thu Oct 19 2006 ro@suse.de
- added mono-devel to buildrequires
* Sun Oct 15 2006 schwab@suse.de
- Use install-data-hook instead of install-hook.
* Tue Aug  1 2006 wberrier@suse.de
- Update to 2.8.3
- Fix: Multiple calls to Gnome.Vfs.MimeType.Description triggers glibc error (77534)
* Mon May  8 2006 joeshaw@suse.de
- Add a patch to make GLib.ValueArray actually free in the main
  GTK thread rather than the finalizer thread.  Fixes deadlocks,
  like bnc #168650.
* Tue Feb 28 2006 wberrier@suse.de
- Update to 2.8.2.  Fixes the following bugs: (Ximian)
  - 77497
  - 77662
  - 77658 (64bit fix, needed by f-spot)
  - 154029 in Novell's Bugzilla
* Tue Feb 21 2006 rguenther@suse.de
- Fix build failure on ppc64.  [#152472]
* Thu Feb 16 2006 wberrier@suse.de
- Add .mdb files.  Fixes: https://bugzilla.novell.com/show_bug.cgi?id=151353
  - also, remove the explicit deps (they are provided by mono(assembly) deps
* Thu Feb  9 2006 wberrier@suse.de
- Update to 2.8.1.  Fixes the following bugs (Ximian bugzilla):
  - #77400
  - #77323
  - #77016
  - #76992
  - #77017
  - #77182
  - #77244
* Fri Feb  3 2006 aj@suse.de
- Cleanup BuildRequires.
- Add Requires for packages.
- Reorder spec file sections.
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 24 2006 wberrier@suse.de
- Additional package splits: art, rsvg, gtkhtml, and gnome-vfs
* Fri Jan 13 2006 wberrier@suse.de
- Redo almost all of the packaging (Novell Bug #142367)
  - split package based on what another distro does
  - clean up nfb a little
  - remove unnecessary hard rpm deps
  - I don't understand why gnome-filesystem would be required?
  - Provide gtk-sharp2-complege virtual package depending on all sub packages
* Wed Jan 11 2006 wberrier@suse.de
- Update to 2.8.0
* Fri Dec 16 2005 wberrier@suse.de
- Update to 2.7.90
* Thu Dec  1 2005 wberrier@suse.de
- Clean up needed for build and install section
* Fri Nov 11 2005 wberrier@suse.de
- Update to 2.7.1
* Thu Oct  6 2005 wberrier@suse.de
- Update to 2.3.92
* Mon Oct  3 2005 gekker@suse.de
- Update to svn snapshot to fix crash when re-sizing windows
- Remove upstreamed patch
* Tue Sep 27 2005 ro@suse.de
- re-enable gtkhtml
* Mon Sep 26 2005 gekker@suse.de
- Fix build on x86_64
* Fri Sep 23 2005 wberrier@suse.de
- updated to 2.3.91.  New version also includes docs for monodoc
* Thu Sep 22 2005 ro@suse.de
- removed libgdiplus-devel from nfb (dropped)
* Sun Sep  4 2005 aj@suse.de
- Add check-build.sh.
* Thu Aug 18 2005 wberrier@suse.de
- Add dependencies on Perl xml packages for gapi (Novell [Bug 105055])
* Mon Jul 11 2005 gekker@suse.de
- fix build with current libgda/libgnomedb
* Wed Jul  6 2005 gekker@suse.de
- Fix to build all optional modules
* Tue Jul  5 2005 gekker@suse.de
- Branch for gtk-sharp2, initial version 1.9.5
* Wed May 18 2005 ro@suse.de
- fix build with current pkgconfig
* Thu May  5 2005 gekker@suse.de
- Fix requires in gtk-sharp to require gtk-sharp-gapi
* Wed Mar 16 2005 gekker@suse.de
- Update to version 1.0.8, leak fixes
- Remove upstreamed patches
* Tue Mar  8 2005 gekker@suse.de
- Update gtkhtml-sharp.diff for new .so version in gtkhtml2
* Tue Mar  8 2005 gekker@suse.de
- add gtkhtml-sharp.diff (66769, 66439)
* Thu Feb 24 2005 gekker@suse.de
- Fix requires (66439)
* Mon Feb 21 2005 clahey@suse.de
- Update to 1.0.6.
* Fri Jan 21 2005 ro@suse.de
- update to 1.0.4
* Fri Jan 14 2005 ro@suse.de
- build with gtkhtml-3.6
* Thu Dec  2 2004 ro@suse.de
- try to fix build on x86_64
* Sun Nov 28 2004 ro@suse.de
- run autoreconf
* Wed Sep  8 2004 joeshaw@suse.de
- Update the gtkhtml patch.
* Tue Sep  7 2004 joeshaw@suse.de
- Add a patch to use gtkhtml 3.1 instead of 3.0.  Ximian #63188
* Fri Sep  3 2004 clahey@suse.de
- Updated to 1.0.
* Mon Jun 28 2004 ro@suse.de
- use rpm scripts for find requires/provides
* Mon Jun 21 2004 clahey@suse.de
- Updated to 0.98.
* Tue May 25 2004 clahey@suse.de
- Initial import.
